Coverage for wagtailsharing/urls.py: 100%

# Coverage for wagtailsharing/urls.py : 100%

## 5 statements 5 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | from __future__ import absolute_import, unicode_literals from django.conf.urls import url from wagtail.wagtailcore.urls import ( serve_pattern, urlpatterns as wagtailcore_urlpatterns ) from wagtailsharing.views import ServeView urlpatterns = [ url(serve_pattern, ServeView.as_view(), name='wagtail_serve') if urlpattern.name == 'wagtail_serve' else urlpattern for urlpattern in wagtailcore_urlpatterns ]